@@ -2,67 +2,11 @@
 # Tests for quintagroup.plonegooglesitemaps
 #
 
-import re, sys
-from urllib import urlencode
-from StringIO import StringIO
-import unittest
-
-from zope.testing import doctestunit
-from zope.component import testing
-from Testing import ZopeTestCase as ztc
-
-from Products.Five import zcml
-from Products.Five import fiveconfigure
-
-from Products.PloneTestCase import PloneTestCase as ptc
-from Products.PloneTestCase.layer import PloneSite
+from base import *
+from zope.component import getSiteManager
+from archetypes.schemaextender.interfaces import ISchemaExtender
 from Products.CMFPlone.utils import _createObjectByType
 
-from XMLParser import parse, hasURL
-
-import quintagroup.plonegooglesitemaps
-from quintagroup.plonegooglesitemaps.config import ping_googlesitemap
-
-quintagroup.plonegooglesitemaps.config.testing = 1
-quintagroup.plonegooglesitemaps.config.UPDATE_CATALOG = True
-
-
-class MixinTestCase:
-    """ Define layer and common afterSetup method with package installation.
-        Package installation on plone site setup impossible because of
-        five's registerPackage directive not recognized on module initializing.
-    """
-    layer = PloneSite
-
-    def afterSetUp(self):
-        self.loginAsPortalOwner()
-
-
-class TestCase(MixinTestCase, ptc.PloneTestCase):
-    """ For unit tests """
-
-class FunctionalTestCase(MixinTestCase, ptc.FunctionalTestCase):
-    """ For functional tests """
-
-# Initialize all needed zcml directives
-fiveconfigure.debug_mode = True
-from Products import Five, CMFCore, GenericSetup
-zcml.load_config('meta.zcml', Five)
-zcml.load_config('meta.zcml', CMFCore)
-zcml.load_config('meta.zcml', GenericSetup)
-zcml.load_config('permissions.zcml', Five)
-
-# Force quintagroup.plonegooglesitemaps zcml initialization
-zcml.load_config('configure.zcml', quintagroup.plonegooglesitemaps)
-fiveconfigure.debug_mode = False
-
-# Install quintagroup.plonegooglesitemaps package and Plone site
-# with the default profile for the package
-PRODUCT = 'quintagroup.plonegooglesitemaps'
-ptc.installPackage(PRODUCT)
-ptc.setupPloneSite( extension_profiles=("%s:default" % PRODUCT,))
-
-
 class TestGoogleSitemapsInstallation(TestCase):
 
     def testType(self):
@@ -107,6 +51,27 @@ class TestGoogleSitemapsInstallation(TestCase):
         self.assert_([1 for ai in cp.listActionInfos() if ai['id']=='GoogleSitemaps'], 
             'No "GoogleSitemaps" configlet added to plone control panel')
 
+    def testNewsSchemaExtenderRegistered(self):
+        lsm = getSiteManager(self.portal)
+        news = self.portal.invokeFactory("News Item", id="test_news")
+        news = getattr(self.portal, "test_news")
+        self.assertNotEqual(lsm.queryAdapter(news, interface=ISchemaExtender), None)
+
+
+class TestGoogleSitemapsUninstallation(TestCase):
+
+    def afterSetUp(self):
+        self.loginAsPortalOwner()
+        qi = self.portal.portal_quickinstaller
+        qi.uninstallProducts(products=['quintagroup.plonegooglesitemaps',])
+        self._refreshSkinData()
+
+    def testNewsSchemaExtenderUnregistered(self):
+        lsm = getSiteManager(self.portal)
+        news = self.portal.invokeFactory("News Item", id="test_news")
+        news = getattr(self.portal, "test_news")
+        self.assertEqual(lsm.queryAdapter(news, interface=ISchemaExtender), None)
+
 
 class TestSitemapType(FunctionalTestCase):
 
@@ -422,6 +387,7 @@ def test_suite():
     from unittest import TestSuite, makeSuite
     suite = TestSuite()
     suite.addTest(makeSuite(TestGoogleSitemapsInstallation))
+    suite.addTest(makeSuite(TestGoogleSitemapsUninstallation))
     suite.addTest(makeSuite(TestSitemapType))
     suite.addTest(makeSuite(TestGoogleSitemaps))
     suite.addTest(makeSuite(TestSettings))
